package auth

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"
	"qnc-server/app/user/cmd/api/internal/logic/auth"
	"qnc-server/app/user/cmd/api/internal/svc"
	"qnc-server/app/user/cmd/api/internal/types"
	"qnc-server/common/result"
	"qnc-server/pkg/lzkit/validator"
)

func RejectAuthorizationHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.RejectAuthorizationReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := auth.NewRejectAuthorizationLogic(r.Context(), svcCtx)
		resp, err := l.RejectAuthorization(&req)
		result.HttpResult(r, w, resp, err)
	}
}
